@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## HTML Object - ~/lib/HTML/Object/Event.pm
-## Version v0.1.0
+## Version v0.2.0
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/12/11
-## Modified 2021/12/11
+## Modified 2022/09/18
 ## All rights reserved
 ## 
 ## 
@@ -17,6 +17,7 @@ BEGIN
     use strict;
     use warnings;
     use parent qw( Module::Generic );
+    use vars qw( @EXPORT_OK %EXPORT_TAGS $VERSION );
     use Nice::Try;
     use Time::HiRes ();
     use constant {
@@ -70,9 +71,12 @@ BEGIN
         )],
         'phase' => [qw( NONE CAPTURING_PHASE AT_TARGET BUBBLING_PHASE )]
     );
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.2.0';
 };
 
+use strict;
+use warnings;
+
 sub init
 {
     my $self = shift( @_ );
@@ -232,7 +236,7 @@ sub timeStamp : lvalue { return( shift->_set_get_datetime( 'timeStamp', @_ ) );
 sub type : lvalue { return( shift->_set_get_lvalue( 'type', @_ ) ); }
 
 1;
-# XXX POD
+# NOTE: POD
 __END__
 
 =encoding utf-8
@@ -249,7 +253,7 @@ HTML::Object::Event - HTML Object Event Class
 
 =head1 VERSION
 
-    v0.1.0
+    v0.2.0
 
 =head1 DESCRIPTION
 
